@@ -2,7 +2,7 @@ from vapoursynth import core
 
 
 class PDebox:
-    """PDebox (PHOENiX Debox)."""
+    """Convenience wrapper for De-boxing operations."""
 
     def __init__(self, clip, aspect_ratio, mode=0, offset=0):
         """
@@ -17,7 +17,7 @@ class PDebox:
         :param clip: VapourSynth Clip (VideoNode) to debox.
         :param aspect_ratio: The Aspect Ratio you wish to crop to, e.g. `"4:3"` to crop to 4:3.
         :param mode: The Direction you wish to crop. `0`=Pillarboxing, `1`=Letterboxing.
-        :param offset: If the content isn't exactly in the center of the frame.
+        :param offset: Alter the cropping window in the same axis as `mode` if the boxing is not centered.
         """
         aspect_ratio = [int(n) for n in aspect_ratio.split(":")]
         aspect_ratio = aspect_ratio[0] / aspect_ratio[1]
