@@ -1,12 +1,11 @@
 import functools
+from typing import List
 
 from vapoursynth import core
 
 
 class PDecimate:
-    """
-    PDecimate (PHOENiX Decimate)
-    """
+    """PDecimate (PHOENiX Decimate)."""
 
     def __init__(self, clip, cycle, offsets, per_vob_id=True, mode=0, debug=False):
         """
@@ -22,7 +21,6 @@ class PDecimate:
         :param debug: Skip decimation and print debugging information. Useful to check if the frames that the cycle
         and offset settings you have provided are correct and actually decimate the right frames.
         """
-
         self.clip = clip
         self.cycle = cycle
         self.offsets = offsets
@@ -57,9 +55,7 @@ class PDecimate:
             self.clip = self._decimate(self.clip, mode, cycle, offsets, debug)
 
     @staticmethod
-    def _decimate(clip, mode, cycle, offsets, debug):
-        if mode < 0 or mode > 1:
-            raise ValueError(f"pvsfunc.decimate: Incorrect mode ({mode}), it must be an int value between 0-1")
+    def _decimate(clip, mode: int, cycle: int, offsets: List[int], debug: bool = False):
         if mode == 0:
             if isinstance(cycle, list):
                 cycle = cycle[0]
@@ -72,8 +68,10 @@ class PDecimate:
                     functools.partial(
                         lambda n, f, c: core.text.Text(
                             c,
-                            f" mode={mode} cycle={cycle} offsets={offsets} fps={res.fps.numerator}/{res.fps.denominator} \n"
-                            f" offset={n % cycle} decimate={(n % cycle) not in offsets} \n",
+                            " mode=%d cycle=%d offsets=%s fps=%d/%d \n" % (
+                                mode, cycle, offsets, res.fps.numerator, res.fps.denominator
+                            ) +
+                            " offset=%d decimate=%s \n" % (n % cycle, (n % cycle) not in offsets),
                             alignment=1
                         ),
                         c=clip
@@ -88,9 +86,9 @@ class PDecimate:
                     functools.partial(
                         lambda n, f, c: core.text.Text(
                             c,
-                            f" mode={mode} cycle={cycle} \n"
+                            " mode=%d cycle=%d \n"
                             " Important: Please consider another mode. More information: git.io/avoid-tdecimate. \n"
-                            f" decimated_frame={f.props['VDecimateDrop'] == 1} \n",
+                            " decimated_frame=%s \n" % (mode, cycle, f.props['VDecimateDrop'] == 1),
                             alignment=1
                         ),
                         c=clip
@@ -98,3 +96,4 @@ class PDecimate:
                     prop_src=core.vivtc.VDecimate(clip, cycle=cycle, dryrun=True)
                 )
             return core.vivtc.VDecimate(clip, cycle=cycle)
+        raise ValueError("pvsfunc.decimate: Incorrect mode (%d), it must be an int value between 0-1" % mode)
